@@ -6,20 +6,20 @@ void Checkupthread::execute() {
     
     while (1) {
 	if (config.checkupsec()) {
-	    msg ("Running checkup thread\n");
+	    msg("Running checkup thread\n");
 	    for (unsigned i = 0; i < balancer.nbackends(); i++) {
 		Backend target(balancer.backend(i).backenddef());
 		try {
 		    target.check();
 		    if (target.live()) {
 			balancer.backend(i).live(true);
-			msg ("Checkup call: backend " + target.description() +
-			     " is alive\n");
+			msg("Checkup call: backend " << target.description()
+			    << " is alive\n");
 		    } else {
 			balancer.backend(i).live(false);
 			balancer.backend(i).markconnecterror();
-			msg ("Checkup call: backend " + target.description() +
-			     " is unavailable\n");
+			msg("Checkup call: backend " << target.description()
+			    << " is unavailable\n");
 			if (config.onfail().length()) {
 			    ostringstream o;
 			    o << config.onfail() << " 0.0.0.0 "
@@ -28,11 +28,14 @@ void Checkupthread::execute() {
 			    sysrun(o.str());
 			}
 		    }
+		} catch (Error &e) {
+		    debugmsg("Error in checkup thread: " << e.what() <<
+			     '\n');
 		} catch (...) {
-		    socketclose(target.sock());
+		    debugmsg("Error in checkup thread\n");
 		}
 	    }
-	    sleep (config.checkupsec());
+	    sleep(config.checkupsec());
 	} else
 	    sleep(30);
     }
