@@ -8,23 +8,31 @@ void Wakeupthread::execute() {
 	    for (unsigned i = 0; i < balancer.nbackends(); i++) {
 		if (! balancer.backend(i).live()) {
 		    Backend target(balancer.backend(i).backenddef());
+		    debugmsg("Wakeup thread: checking " <<
+			     target.description() << '\n');
+		    target.live(balancer.backend(i).live());
 		    try {
 			target.check();
 			if (target.live()) {
-			    msg ("Wakeup call: backend " +
-				 target.description() +
+			    msg ("Wakeup call: backend " << 
+				 target.description() <<
 				 " has awoken\n");
 			    balancer.backend(i).live(true);
 			} else
 			    balancer.backend(i).markconnecterror();
+		    } catch (Error &e) {
+			debugmsg("Exception in wakeup thread: " <<
+				 e.what() << '\n');
 		    } catch (...) {
-			socketclose(target.sock());
+			debugmsg("Exception in wakeup thread\n");
 		    }
 		}
 	    }
 	    sleep (config.wakeupsec());
-	} else
+	} else {
+	    debugmsg("Wakeup thread: no activity right now\n");
 	    sleep(30);
+	}
     }
 }
 
