@@ -1,7 +1,7 @@
 #include "hashedip"
 
 unsigned HashedIp::target(struct in_addr clientip,
-		     BackendVector const &targetlist) {
+		     BackendVector &targetlist) {
 
     // Nothing to do if we don't have targets.
     if (!targetlist.size())
@@ -17,10 +17,8 @@ unsigned HashedIp::target(struct in_addr clientip,
     }
     unsigned index = targetlist[h];
 
-    msg ((Mstr("Client IP ") + static_cast<string>(inet_ntoa(clientip))) +
-	 (Mstr(" hashes to ") + index) +
-	 ", back end " + balancer.backend(index).description() +
-	 "\n");
+    msg("Client IP "<< inet2string(clientip) << " hashes to " << index <<
+	", back end " << balancer.backend(index).description()  << '\n');
 
     // In strict mode, back end must be available, or don't proceed
     // In lax mode, fall back to least-connections dispatching
@@ -30,9 +28,9 @@ unsigned HashedIp::target(struct in_addr clientip,
 			balancer.backend(index).description() +
 			" unavailable");
 	else {
-	    msg ("Hashed-IP algorithm: target back end " +
-		 balancer.backend(index).description() + " unavailable, "
-		 "falling back to least-connections\n");
+	    msg("Hashed-IP algorithm: target back end " <<
+		balancer.backend(index).description() << " unavailable, "
+		<< "falling back to least-connections\n");
 	    Leastconn l;
 	    index = l.target(clientip, targetlist);
 	}
