@@ -1,19 +1,26 @@
 #include "roundrobin"
 
 unsigned Roundrobin::target(struct in_addr clientip,
-			    BackendVector const &targetlist) {
-    // No back ends? Don't even try. One back end? Always that one.
-    if (targetlist.size() == 0)
-	throw Error("Round robin dispatcher: no backends\n");
-
-    if (config.debug())
-	for (unsigned i = 0; i < targetlist.size(); i++) {
-	    unsigned backend_index = targetlist[i];
-	    _debugmsg(Mstr("Round robin dispatcher: target ") +
-		      Mstr(i) + Mstr(" is ") +
-		      balancer.backend(backend_index).description() + "\n");
-	}
-
+			    BackendVector &targetlist) {
+    // Regardless of a pre-existent targetlist, we rebuild it here.
+    // We do that to take weights into accounts. 
+    static bool building;
+    mutex_lock(&building);
+    targetlist.reset();
+    for (unsigned int i = 0; i < balancer.nbackends(); i++)
+	for (unsigned int j = 0; j < balancer.backend(i).weight(); j++)
+	    targetlist.add(i);
+    mutex_unlock(&building);
+    
+    if (config.debug()) {
+	ostringstream o;
+	o << "Round robin target list: ";
+	for (unsigned i = 0; i < targetlist.size(); i++)
+	    o << targetlist[i] << ' ';
+	o << '\n';
+	debugmsg(o.str());
+    }
+    
     if (targetlist.size() == 1)
 	return (targetlist[0]);
     
@@ -39,9 +46,9 @@ unsigned Roundrobin::target(struct in_addr clientip,
 	}
 	
 	// Store for next time 'round
-	lock (&prev_run_index);
+	mutex_lock(&prev_run_index);
 	prev_run_index = cur_val;
-	unlock (&prev_run_index);
+	mutex_unlock(&prev_run_index);
 
 	if (! balancer.backend(targetlist[cur_val]).available())
 	    continue;
