@@ -1,7 +1,7 @@
 #include "weightedload"
 
 unsigned Weightedload::target(struct in_addr clientip,
-			   BackendVector const &targetlist) {
+			   BackendVector &targetlist) {
     // First loop thru and add up the weights.
     double total_load = 0;
     for (unsigned i = 0; i < targetlist.size(); i++) {
@@ -15,9 +15,8 @@ unsigned Weightedload::target(struct in_addr clientip,
     // 4294967295 = 2^32 - 1
     double pick_load = total_load * mt_rand() * (1.0 / 4294967295.0);
 
-    msg ((Mstr("Weighted by Load Average; load-range is ") + total_load) +
-	 (Mstr(", and the selected load-range is ") + pick_load) +
-	 "\n");
+    msg ("Weighted by Load Average; load-range is " << total_load <<
+	 ", and the selected load-range is " << pick_load << '\n');
 
     // Now see which server that means!
     total_load = 0;
