@@ -3,7 +3,7 @@
 void HttpDispatcher::senderrorpage(string const &reason) {
     PROFILE("HttpDispatcher::senderrorpage");
     
-    msg ("Sending error page to client: '" + reason + "'\n");
+    msg("Sending error page to client: '" << reason << "'\n");
     try {
 	string txt =
 	    "<html>\n"
@@ -12,7 +12,8 @@ void HttpDispatcher::senderrorpage(string const &reason) {
 	    " </head>\n"
 	    " <body>\n"
 	    "  <h1>Internal Server Error</h1>\n"
-	    "  You request could not be completed. Please retry later.\n"
+	    "  You request could not be completed. Please retry later.<p/>"
+	    "  (" + reason + ")\n"
 	    " </body>\n"
 	    "</html>\n";
 	ostringstream mess;
@@ -27,6 +28,6 @@ void HttpDispatcher::senderrorpage(string const &reason) {
     } catch (Error const &e) {
 	// Silently discard, we are not interested in errors
 	// that ocur when an error page is being sent
-	msg (Mstr(e.what()) + Mstr(" (while sending error page)\n"));
+	msg (e.what() << " (while sending error page)\n");
     }
 }
