@@ -2,18 +2,19 @@
 
 void TcpDispatcher::handle() {
     
-    debugmsg (Mstr("TCP dispatcher: About to shuttle between client fd ") +
-	      clientfd() +
-	      (Mstr(" and backend fd ") + backendfd()) + "\n");
+    debugmsg("TCP dispatcher: About to shuttle between client fd " <<
+	     clientfd().fd() << " and backend fd " << backendfd().fd() <<
+	     '\n');
     
+    Fdset readset(maxtimeout(config.client_read_timeout(),
+			     config.backend_read_timeout()));
+    readset.add(clientfd());
+    readset.add(backendfd());
     while (1) {
-	Fdset readset(maxtimeout(config.client_read_timeout(),
-				 config.backend_read_timeout()));
-	readset.add(clientfd());
-	readset.add(backendfd());
-	readset.wait_r();
-	
-	int sock, othersock, timeout;
+	Socket sock, othersock;
+	int timeout;
+
+	readset.wait_r();	
 	if (readset.readable(clientfd())) {
 	    sock = clientfd();
 	    othersock = backendfd();
@@ -27,13 +28,14 @@ void TcpDispatcher::handle() {
 
 	if (!netbuffer.netread(sock))
 	    break;
-	debugmsg (Mstr("Had data on ") + sock +
-		  (Mstr(", sending to ") + othersock) + "\n");
+	debugmsg("Had data on " << sock.fd() <<
+		 ", sending to " << othersock.fd() << '\n');
 	netbuffer.netwrite (othersock, timeout);
 	if (sock == backendfd())
 	    balancer.backend(targetbackend()).addbytes(netbuffer.bufsz());
 	else
-	    IPStore::activity(clientip(), targetbackend());
+	    IPStore::activity(clientfd().clientaddr().sin_addr,
+			      targetbackend());
 
 	netbuffer.reset();
     }
