@@ -4,17 +4,21 @@
 void *Thread::_run (void *data) {
     Thread *t = (Thread*) data;
 
-    debugmsg(Mstr("Thread: starting run\n"));
+    debugmsg("Thread: starting run\n");
     Threadlist::enregister();    
     try {
 	t->execute();
     } catch (Error const &e) {
-	lock(&cerr);
+	mutex_lock(&cerr);
+	if (config.prefixtimestamp()) {
+	    Timestamp tm;
+	    cerr << tm.desc() << ' ';
+	}
 	cerr << e.what() << "\n";
-	unlock(&cerr);
+	mutex_unlock(&cerr);
     }
     Threadlist::deregister();
-    debugmsg(Mstr("Thread: ending run\n"));
+    debugmsg("Thread: ending run\n");
 
     // Cleanups
     delete (t);
