@@ -17,11 +17,11 @@ void Thread::start() {
 	    throw Error("Cannot set thread state as detached");
 	for (int i = 0; i < 3; i++) {
 #	    ifdef MISTRUST_THREAD_CREATE_THREADSAFE
-	    lock((void*)_run);
+	    mutex_lock((void*)_run);
 #	    endif	    
 	    res = pthread_create (&th, &attr, _run, (void*) this);
 #	    ifdef MISTRUST_THREAD_CREATE_THREADSAFE
-	    unlock((void*)_run);
+	    mutex_unlock((void*)_run);
 #	    endif	    
 	    if (!res) {
 		pthread_attr_destroy (&attr);
