@@ -1,7 +1,7 @@
 #include "threadlist"
 
 void Threadlist::deregister(pthread_t id) {
-    Mutex::lock(&th_map);
+    mutex_lock(&th_map);
     th_map.erase(id);
-    Mutex::unlock(&th_map);
+    mutex_unlock(&th_map);
 }
