@@ -4,7 +4,7 @@ Threadmap Threadlist::th_map;
 
 void Threadlist::enregister() {
     Threadinfo n;
-    Mutex::lock(&th_map);
+    mutex_lock(&th_map);
     th_map[pthread_self()] = n;
-    Mutex::unlock(&th_map);
+    mutex_unlock(&th_map);
 }
