@@ -1,7 +1,8 @@
 #include "backend"
 
 void Backend::addbytes (unsigned n) {
-    Mutex::lock (&bytes_served);
+    static int lock;
+    mutex_lock(&lock);
     bytes_served += n;
-    Mutex::unlock (&bytes_served);
+    mutex_unlock (&lock);
 }
