@@ -5,15 +5,13 @@
 bool Backend::available() const {
     PROFILE("Backend::available");
 
-    if (config.debug()) {
-	ostringstream o;
-	o << "Back end " << description() << ": "
-	  << livestr() << ", " << upstr() << ", "
-	  << connections() << " connections, "
-	  << IPStore::anticipated(balancerindex()) << " anticipated, "
-	  << maxconn() << " max\n";
-	_debugmsg(o.str());
-    }
+    /*
+    debugmsg("Back end " << description() << ": "
+	     << livestr() << ", " << upstr() << ", "
+	     << connections() << " connections, "
+	     << IPStore::anticipated(balancerindex()) << " anticipated, "
+	     << maxconn() << " max\n");
+    */
     if (!maxconn())
 	return (islive && isup);
     return (islive &&
