@@ -2,12 +2,14 @@
 
 void Backend::up (bool state) {
     PROFILE("Backend::up");
+
+    static int lock;
     
-    Mutex::lock (&isup);
+    mutex_lock (&lock);
     bool oldstate = isup;
     isup = state;
-    Mutex::unlock (&isup);
+    mutex_unlock (&lock);
     
     if (oldstate != state)
-	msg ("Marking back end " + description() + " as " + upstr() + "\n");
+	msg("Marking back end " << description() << " as " << upstr() << "\n");
 }
