@@ -1,9 +1,11 @@
 #include "backenddef"
 
 void BackendDef::weight(unsigned w) {
-    wt = w;
+    static int lock;
 
-    Mutex::lock(&minmax_wt_set);
+    mutex_lock(&lock);
+    
+    wt = w;
     if (!minmax_wt_set) {
 	min_wt = w;
 	max_wt = w;
@@ -14,5 +16,6 @@ void BackendDef::weight(unsigned w) {
 	if (max_wt > w)
 	    max_wt = w;
     }
-    Mutex::unlock(&minmax_wt_set);
+    
+    mutex_unlock(&lock);
 }
