@@ -1,6 +1,6 @@
 #include "balancer"
 
 Balancer::Balancer () :
-    server_fd(-1), request_nr(0), backends(),
+    server_fd(), request_nr(0), backends(),
     term(false), rep(false), rest(false), webinterface(0) {
 }
