@@ -10,8 +10,9 @@ void Balancer::deletebackend(unsigned i) {
 	throw Error(o.str());
     }
 
-    Mutex::lock(&backends);
+    int lock;
+    mutex_lock(&lock);
     backends.erase(backends.begin() + i,
 		   backends.begin() + i + 1);
-    Mutex::unlock(&backends);
+    mutex_unlock(&lock);
 }
