@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::addserverheader (string const &s) {
-    Mutex::lock (&serverheaders);
+    int lock;
+    
+    mutex_lock (&lock);
     serverheaders.push_back (s);
-    Mutex::unlock (&serverheaders);
+    mutex_unlock (&lock);
 }
