@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::addxforwardedfor(bool b) {
-    Mutex::lock (&add_x_forwarded_for);
+    int lock;
+    
+    mutex_lock (&lock);
     add_x_forwarded_for = b;
-    Mutex::unlock (&add_x_forwarded_for);
+    mutex_unlock (&lock);
 }
