@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::addxrversion(bool b) {
-    Mutex::lock (&add_xr_version);
+    int lock;
+    
+    mutex_lock (&lock);
     add_xr_version = b;
-    Mutex::unlock (&add_xr_version);
+    mutex_unlock (&lock);
 }
