@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::buffersize(unsigned b) {
-    Mutex::lock (&bufsize);
+    int lock;
+    
+    mutex_lock (&lock);
     bufsize = b;
-    Mutex::unlock (&bufsize);
+    mutex_unlock (&lock);
 }
