@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::changeserverheader (unsigned i, string const &s) {
-    Mutex::lock (&serverheaders);
+    int lock;
+    
+    mutex_lock (&lock);
     serverheaders[i] = s;
-    Mutex::unlock (&serverheaders);
+    mutex_unlock (&lock);
 }
