@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::fastclose(bool b) {
-    Mutex::lock (&fast_close);
+    int lock;
+    
+    mutex_lock (&lock);
     fast_close = b;
-    Mutex::unlock (&fast_close);
+    mutex_unlock (&lock);
 }
