@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::ipstoretimeout (int t) {
-    Mutex::lock (&ipstore_timeout);
+    int lock;
+    
+    mutex_lock (&lock);
     ipstore_timeout = t;
-    Mutex::unlock (&ipstore_timeout);
+    mutex_unlock (&lock);
 }
