@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::maxconn (unsigned m) {
-    Mutex::lock (&max_conn);
+    int lock;
+    
+    mutex_lock (&lock);
     max_conn = m;
-    Mutex::unlock (&max_conn);
+    mutex_unlock (&lock);
 }
