@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::pidfile (string const &p) {
-    Mutex::lock (&pid_file);
+    int lock;
+    
+    mutex_lock (&lock);
     pid_file = p;
-    Mutex::unlock (&pid_file);
+    mutex_unlock (&lock);
 }
