@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::prefixtimestamp(bool b) {
-    Mutex::lock (&prefix_timestamp);
+    int lock;
+    
+    mutex_lock (&lock);
     prefix_timestamp = b;
-    Mutex::unlock (&prefix_timestamp);
+    mutex_unlock (&lock);
 }
