@@ -1,8 +1,10 @@
 #include "config"
 
 void Config::removeserverheader (unsigned i) {
-    Mutex::lock (&serverheaders);
+    int lock;
+    
+    mutex_lock (&lock);
     serverheaders.erase (serverheaders.begin() + i,
 			 serverheaders.begin() + i + 1);
-    Mutex::unlock (&serverheaders);
+    mutex_unlock (&lock);
 }
