@@ -1,7 +1,9 @@
 #include "config"
 
 void Config::stickyhttp (bool b) {
-    Mutex::lock (&sticky_http);
+    int lock;
+    
+    mutex_lock (&lock);
     sticky_http = b;
-    Mutex::unlock (&sticky_http);
+    mutex_unlock (&lock);
 }
