@@ -7,14 +7,14 @@ in_addr_t &DNSEntry::resolve (string const &h) {
 
     // Resolve now.
     struct hostent *hostaddr;
-    Mutex::lock((void*)gethostbyname);
+    mutex_lock((void*)gethostbyname);
     if ( (hostaddr = gethostbyname(h.c_str())) )
 	memcpy (&result, hostaddr->h_addr_list[0], hostaddr->h_length);
-    Mutex::unlock((void*)gethostbyname);
+    mutex_unlock((void*)gethostbyname);
 
     if (!hostaddr)
 	throw Error("Failed to resolve host '" + h + "'");
 
-    debugmsg(Mstr("Host ") + h + " resolved\n");
+    debugmsg("Host " << h << " resolved\n");
     return result;
 }
