@@ -17,6 +17,6 @@ string Httpbuffer::cookievalue (string c) {
 	    ret += ch;
 	}
     }
-    msg(Mstr("Cookie value '") + c + Mstr("' : '") + ret + "'\n");
+    msg("Cookie value '" << c << "' : '" << ret << "'\n");
     return (ret);
 }
