@@ -16,6 +16,6 @@ string Httpbuffer::paramvalue (string c) {
 	     ch = uri[++pos])
 	    ret += ch;
     }
-    msg(Mstr("Param value '") + c + Mstr("' : '") + ret + "'\n");
+    msg("Param value '" << c << "' : '" << ret << "'\n");
     return ret;
 }
