@@ -4,12 +4,14 @@ void IPStore::activity(struct in_addr clientip, unsigned curbackend) {
     if (!onoff)
 	return;
 
-    msg(Mstr("Logging activity for back end ") + Mstr(curbackend) +
-	     Mstr(" from ") + inet_ntoa(clientip) + "\n");
+    msg("Logging activity for back end " << curbackend << 
+	" from " << inet2string(clientip) << '\n');
+
+    int lock;
     
-    Mutex::lock(&store);
+    mutex_lock(&lock);
     store[clientip].targetbackend = (int)curbackend;
     store[clientip].lastaccess = time(0);
-    Mutex::unlock(&store);
+    mutex_unlock(&lock);
 }
     
