@@ -9,17 +9,18 @@ unsigned IPStore::anticipated(unsigned b) {
 
     // Get number of anticipated clients for given back end
     unsigned ret = 0;
+    static int lock;
 
-    Mutex::lock(&store);
+    mutex_lock(&lock);
     for (StoreMap::iterator iter = store.begin();
 	 iter != store.end();
 	 iter++)
 	if ((*iter).second.targetbackend == (int)b)
 	    ret++;
-    Mutex::unlock(&store);
+    mutex_unlock(&lock);
 
-    debugmsg(Mstr("Anticipated connections for back end ") + Mstr(b) + ": " +
-	     Mstr(ret) + "\n");
+    debugmsg("Anticipated connections for back end " << b << ": " <<
+	     ret << '\n');
     return ret;
 }
    
