@@ -4,8 +4,9 @@ void IPStore::clearoldest() {
     time_t oldest_time = time(0) + 100;
     StoreMap::iterator oldest_entry;
     bool found = false;
+    static int lock;
 
-    Mutex::lock(&store);
+    mutex_lock(&lock);
 
     dump();
     
@@ -24,13 +25,13 @@ void IPStore::clearoldest() {
     if (found) {
 	if (config.debug()) {
 	    Timestamp tm((*oldest_entry).second.lastaccess);
-	    _debugmsg(Mstr("Erasing oldest IP store entry: ") +
-		      Mstr(inet_ntoa(oldest_entry->first)) + " on " +
-		      tm.desc() + "\n");
+	    debugmsg("Erasing oldest IP store entry: " << 
+		     inet2string(oldest_entry->first) << " on " <<
+		     tm.desc() << '\n');
 	}
 	store.erase(oldest_entry);
     }
 
-    Mutex::unlock(&store);
+    mutex_unlock(&lock);
     dump();
 }
