@@ -4,15 +4,15 @@ void IPStore::dump() {
     if (!config.debug())
 	return;
 
-    _debugmsg(Mstr("IPStore dump:\n"));
+    debugmsg("IPStore dump:\n");
     for (StoreMap::iterator iter = store.begin();
 	 iter != store.end();
 	 iter++) {
 	Timestamp tm((*iter).second.lastaccess);
 	ostringstream o;
-	o << "Client IP " << inet_ntoa(iter->first) << " on "
+	o << "Client IP " << inet2string(iter->first) << " on "
 	  << tm.desc() << " to back end " << (*iter).second.targetbackend
 	  << '\n';
-	_debugmsg(o.str());
+	debugmsg(o.str());
     }
 }
