@@ -11,10 +11,10 @@ int IPStore::target(struct in_addr clientip) {
     if (store.count(clientip) > 0) {
 	if (config.verbose()) {
 	    Timestamp tm(store[clientip].lastaccess);
-	    msg(Mstr("Client IP ") + Mstr(inet_ntoa(clientip)) +
-		" last visited on " + tm.desc() + " and went to " +
-		balancer.backend(store[clientip].targetbackend).description() +
-		"\n");
+	    msg("Client IP " << inet2string(clientip) << 
+		" last visited on " << tm.desc() << " and went to " <<
+		balancer.backend(store[clientip].targetbackend).description()
+		<< '\n');
 	}
 	return store[clientip].targetbackend;
     }
