@@ -3,8 +3,9 @@
 void IPStore::weed() {
     time_t now = time(0);
     bool done = false;
+    static int lock;
     
-    Mutex::lock(&store);
+    mutex_lock(&lock);
 
     while (!done) {
 	done = true;
@@ -14,9 +15,8 @@ void IPStore::weed() {
 	    if (now - ((*iter).second.lastaccess) > config.ipstoretimeout()) {
 		if (config.debug()) {
 		    Timestamp tm((*iter).second.lastaccess);
-		    _debugmsg (Mstr("Stale entry: ") + Mstr(inet_ntoa(iter->first)) +
-			       Mstr(" visited on ") + tm.desc() +
-			       ", erasing\n");
+		    debugmsg ("Stale entry: " << inet2string(iter->first) <<
+			      " visited on " << tm.desc() << ", erasing\n");
 		}
 		done = false;
 		store.erase(iter);
@@ -25,5 +25,5 @@ void IPStore::weed() {
 	}
     }
     
-    Mutex::unlock(&store);
+    mutex_unlock(&lock);
 }
