@@ -1,13 +1,15 @@
 #include "memory"
 
 void Memory::mem_display() {
-    Mutex::lock(&s_memlog);
+    static int lock;
+    
+    mutex_lock(&lock);
     for (unsigned i = 0; i < s_memlog.size(); i++) {
 	MemoryEntry ent = s_memlog[i];
-	Mutex::lock(&cout);
+	mutex_lock(&cout);
 	cout << "Memory::mem_display " << ent.ptr << ' ' << ent.sz
 	     << ' ' << ent.desc << '\n';
-	Mutex::unlock(&cout);
+	mutex_unlock(&cout);
     }
-    Mutex::unlock(&s_memlog);
+    mutex_unlock(&lock);
 }
