@@ -3,21 +3,23 @@
 void Memory::free(void *ptr) {
     if (!ptr)
 	return;
+
+    static int lock;
     
     for (unsigned i = 0; i < s_memlog.size(); i++) {
-	Mutex::lock(&s_memlog);
+	mutex_lock(&lock);
 	MemoryEntry ent = s_memlog[i];
-	Mutex::unlock(&s_memlog);
+	mutex_unlock(&lock);
 	if (ent.ptr == ptr) {
 	    if (s_follow) {
-		Mutex::lock(&cout);
+		mutex_lock(&cout);
 		cout << "Memory::free(" << ptr << ")\n";
-		Mutex::unlock(&cout);
+		mutex_unlock(&cout);
 	    }
 	    ::free (ent.ptr);
-	    Mutex::lock(&s_memlog);
+	    mutex_lock(&lock);
 	    s_memlog.erase(s_memlog.begin() + i);
-	    Mutex::unlock(&s_memlog);
+	    mutex_unlock(&lock);
 	    return;
 	}
     }
