@@ -1,16 +1,18 @@
 #include "memory"
 
 void *Memory::malloc(size_t sz, string const &desc) {
+    static int lock;
     void *ptr = ::malloc(sz);
     MemoryEntry ent = { ptr, sz, desc };
-    Mutex::lock(&s_memlog);
+    
+    mutex_lock(&lock);
     s_memlog.push_back(ent);
-    Mutex::unlock(&s_memlog);
+    mutex_unlock(&lock);
     if (s_follow) {
-	Mutex::lock(&cout);
+	mutex_lock(&cout);
 	cout << "Memory::malloc(" << sz << ") -> " << ptr << ' '
 	     << desc << '\n';
-	Mutex::unlock(&cout);
+	mutex_unlock(&cout);
     }
     return ptr;
 }
