@@ -2,7 +2,9 @@
 
 void Memory::mem_mark(string const &desc) {
     MemoryEntry ent = { 0, 0, "MARK " + desc };
-    Mutex::lock(&s_memlog);
+    static int lock;
+    
+    mutex_lock(&lock);
     s_memlog.push_back(ent);
-    Mutex::unlock(&s_memlog);
+    mutex_unlock(&lock);
 }
