@@ -1,6 +1,8 @@
 #include "memory"
 
 void *Memory::realloc(void *ptr, size_t newsz, string const &desc) {
+    static int lock;
+    
     if (!newsz) {
 	free(ptr);
 	return 0;
@@ -11,14 +13,14 @@ void *Memory::realloc(void *ptr, size_t newsz, string const &desc) {
 		ent.ptr = ::realloc(ptr, newsz);
 		ent.sz = newsz;
 		ent.desc = desc;
-		Mutex::lock(&s_memlog);
+		mutex_lock(&lock);
 		s_memlog[i] = ent;
-		Mutex::unlock(&s_memlog);
+		mutex_unlock(&lock);
 		if (s_follow) {
-		    Mutex::lock(&cout);
+		    mutex_lock(&cout);
 		    cout << "Memory::realloc(" << ptr << ", " << newsz
 			 << ") -> " << ent.ptr << ' ' << desc << '\n';
-		    Mutex::unlock(&cout);
+		    mutex_unlock(&cout);
 		}
 		return ent.ptr;
 	    }
