@@ -11,7 +11,7 @@ void Netbuffer::check_space(unsigned extra) {
 	if (extra == config.buffersize() &&
 	    config.stype() == Servertype::t_http)
 	    buf_alloced <<= 1;
-	debugmsg (Mstr("Netbuffer: reserving ") + buf_alloced +
+	debugmsg("Netbuffer: reserving " << buf_alloced <<
 		  " bytes for network buffer\n");
 	LOCK_MALLOC;
 	buf_data = (char*)malloc(buf_alloced);
@@ -19,9 +19,9 @@ void Netbuffer::check_space(unsigned extra) {
 	if (! buf_data)
 	    throw Error("Memory fault in Netbuffer::check_space");
     } else if (buf_sz + extra > buf_alloced) {
-	debugmsg((Mstr("Netbuffer: reallocating net buffer from ") +
-		  buf_alloced) +
-		 (Mstr(" to ") + (buf_alloced + extra)) + " bytes\n");
+	debugmsg("Netbuffer: reallocating net buffer from " <<
+		 buf_alloced << " to " <<
+		 (buf_alloced + extra) << " bytes\n");
 	buf_alloced += extra;
 	LOCK_MALLOC;
 	buf_data = (char*)realloc(buf_data, buf_alloced);
