@@ -1,8 +1,8 @@
 #include "netbuffer"
 
 void Netbuffer::destroy() {
-    debugmsg(Mstr("Netbuffer: destroying ") + Mstr(buf_alloced) +
-	     Mstr( " bytes\n"));
+    if (buf_alloced)
+	debugmsg("Netbuffer: destroying " << buf_alloced << " bytes\n");
     free(buf_data);
     buf_data 	= 0;
     buf_sz 	= 0;
