@@ -2,12 +2,17 @@
 
 bool Netbuffer::insertat(unsigned index, char const *s, unsigned len) {
     PROFILE("Netbuffer::insertat");
-    debugmsg(Mstr("Netbuffer: inserting ") + Mstr(s) + Mstr(" at ") +
-	     Mstr(index) + "\n");
 
     if (!len)
 	len = strlen(s);
 
+    if (config.debug()) {
+	string pr;
+	for (unsigned int i = 0; i < len; i++)
+	    pr += printable(s[i]);
+	debugmsg("Netbuffer: inserting " << pr << " at " << index << '\n');
+    }
+    
     if (index >= buf_sz)
 	return false;
     check_space(len);
