@@ -1,5 +1,5 @@
 #include "netbuffer"
 
 Netbuffer::Netbuffer(): buf_data(0), buf_sz(0), buf_alloced(0) {
-    debugmsg(Mstr("Netbuffer: creating zero size buffer\n"));
+    debugmsg("Netbuffer: creating zero size buffer\n");
 }
