@@ -1,7 +1,7 @@
 #include "netbuffer"
 
 Netbuffer const &Netbuffer::operator= (Netbuffer const &other) {
-    debugmsg(Mstr("Netbuffer: copying other\n"));
+    debugmsg("Netbuffer: copying other\n");
     if (this != &other) {
 	destroy();
 	copy (other);
