@@ -1,7 +1,7 @@
 #include "netbuffer"
 
 void Netbuffer::setstring(string const &s) {
-    debugmsg(Mstr("Netbuffer: setting to string\n"));
+    debugmsg("Netbuffer: setting to string\n");
     
     destroy();
     check_space(s.size() + 1);    
