@@ -7,9 +7,7 @@ void Servertype::type (string id) {
 	t = t_tcp;
     else if (id == "http")
 	t = t_http;
-    else if (id == "udp")
-	t = t_udp;
     else
 	throw Error("Bad server type '" + id +
-		    "', supported are 'tcp' or 'http' or 'udp'");
+		    "', supported are 'tcp' or 'http'");
 }
