@@ -7,8 +7,6 @@ string Servertype::typestr() const {
 	return ("tcp");
     else if (t == t_http)
 	return ("http");
-    else if (t == t_udp)
-	return ("udp");
     else
 	throw Error("Server type unknown in Servertype::typestr");
 }
