@@ -9,9 +9,9 @@ bool ipmatch (struct in_addr adr, struct in_addr mask) {
     memcpy (&lmask, &mask, sizeof(mask));
     bool match = ( (laddr & lmask) == laddr );
 
-    debugmsg ("Matching ip " + (string)inet_ntoa(adr) + " against mask " +
-	      (string)inet_ntoa(mask) + ": " +
-	      (match ? "match" : "miss") + "\n");
+    debugmsg("Matching ip " << inet2string(adr) << " against mask " <<
+	     inet2string(mask) << ": " <<
+	     (match ? "match" : "miss") << '\n');
     
     return (match);
 }
